@@ -21,7 +21,7 @@ use warnings;
 no warnings qw(recursion);
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '3.000000';
+$VERSION        = '3.001_001';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -1365,6 +1365,7 @@ sub Marpa::R2::Internal::ASF::Traverse::all_choices {
         my @new_results = ();
         for my $old_result (@results) {
             my $child_value = $values[$rh_ix];
+            $child_value = [ $child_value ] unless ref $child_value eq 'ARRAY';
             for my $new_value ( @{ $child_value } ) {
                 push @new_results, [ @{$old_result}, $new_value ];
             }
